# tep

`tep` is a testing tool to help you write pytest more easily. Try Easy Pytest!

# Design Philosophy

- Quickly create automated test projects
- Useful third party package integration
- Code is better than config

# Key Features

- Inherit all features of `requests`，what `tep.client.request` adds is just a little log.
- The `fixtures` directory is automatically imported by `conftest.py`.
- Make full use of `@pytest.fixture`, preset the global environment variables `env_vars` and login api `login`. 
- A single parameter `--tep-reports` generates the allure html test report.
- Integrate common packages such as `faker`, `jmespath`, `loguru`, `pytest-xdist`, `pytest-assume`.
- Provide a `requirements.txt` that contains some extension packages for optional manual installation.
- Gives one of pytest's best practices in automated testing.

# Installation

`tep` is developed with Python, it supports Python `3.6+` and most operating systems.

`tep` is available on [`PyPI`](https://pypi.python.org/pypi) and can be installed through `pip`.

```
$ pip install tep
```

or domestic mirror.

```
$ pip --default-timeout=600 install -i https://pypi.tuna.tsinghua.edu.cn/simple tep
```

# Check Installation

When tep is installed, tep command will be added in your system.

To see `tep` version:

```
$ tep -V  # tep --version
0.2.3
```

# Usage

If you want to know more usages, you can read [pytest docs](https://docs.pytest.org/).

You know pytest.

You know tep.
